@@ -7,7 +7,7 @@ import litellm
 import os
 
 
-class APIScorer(str, Enum):
+class APIScorerType(str, Enum):
     """
     Collection of proprietary scorers implemented by Judgment.
 
@@ -15,23 +15,17 @@ class APIScorer(str, Enum):
     Examples via the Judgment API.
     """
 
-    FAITHFULNESS = "faithfulness"
-    ANSWER_RELEVANCY = "answer_relevancy"
-    ANSWER_CORRECTNESS = "answer_correctness"
-    HALLUCINATION = "hallucination"
-    SUMMARIZATION = "summarization"
-    CONTEXTUAL_RECALL = "contextual_recall"
-    CONTEXTUAL_RELEVANCY = "contextual_relevancy"
-    CONTEXTUAL_PRECISION = "contextual_precision"
-    INSTRUCTION_ADHERENCE = "instruction_adherence"
-    EXECUTION_ORDER = "execution_order"
-    JSON_CORRECTNESS = "json_correctness"
-    COMPARISON = "comparison"
-    GROUNDEDNESS = "groundedness"
-    DERAILMENT = "derailment"
-    TOOL_ORDER = "tool_order"
-    CLASSIFIER = "classifier"
-    TOOL_DEPENDENCY = "tool_dependency"
+    PROMPT_SCORER = "Prompt Scorer"
+    FAITHFULNESS = "Faithfulness"
+    ANSWER_RELEVANCY = "Answer Relevancy"
+    ANSWER_CORRECTNESS = "Answer Correctness"
+    INSTRUCTION_ADHERENCE = "Instruction Adherence"
+    EXECUTION_ORDER = "Execution Order"
+    DERAILMENT = "Derailment"
+    TOOL_ORDER = "Tool Order"
+    CLASSIFIER = "Classifier"
+    TOOL_DEPENDENCY = "Tool Dependency"
+    CUSTOM = "Custom"
 
     @classmethod
     def _missing_(cls, value):
@@ -41,40 +35,10 @@ class APIScorer(str, Enum):
                 return member
 
 
-UNBOUNDED_SCORERS = set(
-    [APIScorer.COMPARISON]
+UNBOUNDED_SCORERS: set[APIScorerType] = (
+    set()
 )  # scorers whose scores are not bounded between 0-1
 
-ROOT_API = os.getenv("JUDGMENT_API_URL", "https://api.judgmentlabs.ai")
-# API URLs
-JUDGMENT_EVAL_API_URL = f"{ROOT_API}/evaluate/"
-JUDGMENT_TRACE_EVAL_API_URL = f"{ROOT_API}/evaluate_trace/"
-JUDGMENT_DATASETS_PUSH_API_URL = f"{ROOT_API}/datasets/push/"
-JUDGMENT_DATASETS_APPEND_EXAMPLES_API_URL = f"{ROOT_API}/datasets/insert_examples/"
-JUDGMENT_DATASETS_PULL_API_URL = f"{ROOT_API}/datasets/pull_for_judgeval/"
-JUDGMENT_DATASETS_DELETE_API_URL = f"{ROOT_API}/datasets/delete/"
-JUDGMENT_DATASETS_EXPORT_JSONL_API_URL = f"{ROOT_API}/datasets/export_jsonl/"
-JUDGMENT_DATASETS_PROJECT_STATS_API_URL = f"{ROOT_API}/datasets/fetch_stats_by_project/"
-JUDGMENT_DATASETS_INSERT_API_URL = f"{ROOT_API}/datasets/insert_examples/"
-JUDGMENT_EVAL_LOG_API_URL = f"{ROOT_API}/log_eval_results/"
-JUDGMENT_EVAL_FETCH_API_URL = f"{ROOT_API}/fetch_experiment_run/"
-JUDGMENT_EVAL_DELETE_API_URL = (
-    f"{ROOT_API}/delete_eval_results_by_project_and_run_names/"
-)
-JUDGMENT_EVAL_DELETE_PROJECT_API_URL = f"{ROOT_API}/delete_eval_results_by_project/"
-JUDGMENT_PROJECT_DELETE_API_URL = f"{ROOT_API}/projects/delete/"
-JUDGMENT_PROJECT_CREATE_API_URL = f"{ROOT_API}/projects/add/"
-JUDGMENT_TRACES_FETCH_API_URL = f"{ROOT_API}/traces/fetch/"
-JUDGMENT_TRACES_SAVE_API_URL = f"{ROOT_API}/traces/save/"
-JUDGMENT_TRACES_UPSERT_API_URL = f"{ROOT_API}/traces/upsert/"
-JUDGMENT_TRACES_DELETE_API_URL = f"{ROOT_API}/traces/delete/"
-JUDGMENT_TRACES_ADD_ANNOTATION_API_URL = f"{ROOT_API}/traces/add_annotation/"
-JUDGMENT_TRACES_SPANS_BATCH_API_URL = f"{ROOT_API}/traces/spans/batch/"
-JUDGMENT_TRACES_EVALUATION_RUNS_BATCH_API_URL = (
-    f"{ROOT_API}/traces/evaluation_runs/batch/"
-)
-JUDGMENT_ADD_TO_RUN_EVAL_QUEUE_API_URL = f"{ROOT_API}/add_to_run_eval_queue/"
-JUDGMENT_GET_EVAL_STATUS_API_URL = f"{ROOT_API}/get_evaluation_status/"
 # RabbitMQ
 RABBITMQ_HOST = os.getenv(
     "RABBITMQ_HOST", "rabbitmq-networklb-faa155df16ec9085.elb.us-west-1.amazonaws.com"
@@ -151,3 +115,6 @@ MAX_WORKER_THREADS = 10
 
 # Maximum number of concurrent operations for evaluation runs
 MAX_CONCURRENT_EVALUATIONS = 50  # Adjust based on system capabilities
+
+# Span lifecycle management
+SPAN_LIFECYCLE_END_UPDATE_ID = 20  # Default ending number for completed spans
