@@ -1,5 +1,4 @@
 from judgeval.data.example import Example, ExampleParams
-from judgeval.data.custom_example import CustomExample
 from judgeval.data.scorer_data import ScorerData, create_scorer_data
 from judgeval.data.result import ScoringResult, generate_scoring_result
 from judgeval.data.trace import Trace, TraceSpan, TraceUsage
@@ -8,7 +7,6 @@ from judgeval.data.trace import Trace, TraceSpan, TraceUsage
 __all__ = [
     "Example",
     "ExampleParams",
-    "CustomExample",
     "ScorerData",
     "create_scorer_data",
     "ScoringResult",
