@@ -4,13 +4,13 @@ Implementation of using TogetherAI inference for judges.
 
 from pydantic import BaseModel
 from typing import List, Union
-from judgeval.common.logger import debug, error
 
 from judgeval.judges import JudgevalJudge
 from judgeval.common.utils import (
     fetch_together_api_response,
     afetch_together_api_response,
 )
+from judgeval.common.logger import judgeval_logger
 
 BASE_CONVERSATION = [
     {"role": "system", "content": "You are a helpful assistant."},
@@ -19,14 +19,12 @@ BASE_CONVERSATION = [
 
 class TogetherJudge(JudgevalJudge):
     def __init__(self, model: str = "Qwen/Qwen2.5-72B-Instruct-Turbo", **kwargs):
-        debug(f"Initializing TogetherJudge with model={model}")
         self.model = model
         self.kwargs = kwargs
         super().__init__(model_name=model)
 
     # TODO: Fix cost for generate and a_generate
     def generate(self, input: Union[str, List[dict]], schema: BaseModel = None) -> str:
-        debug(f"Generating response for input type: {type(input)}")
         if isinstance(input, str):
             convo = BASE_CONVERSATION + [{"role": "user", "content": input}]
             return fetch_together_api_response(
@@ -38,13 +36,12 @@ class TogetherJudge(JudgevalJudge):
                 self.model, convo, response_format=schema
             )
         else:
-            error(f"Invalid input type received: {type(input)}")
+            judgeval_logger.error(f"Invalid input type received: {type(input)}")
             raise TypeError("Input must be a string or a list of dictionaries.")
 
     async def a_generate(
         self, input: Union[str, List[dict]], schema: BaseModel = None
     ) -> str:
-        debug(f"Async generating response for input type: {type(input)}")
         if isinstance(input, str):
             convo = BASE_CONVERSATION + [{"role": "user", "content": input}]
             res = await afetch_together_api_response(
@@ -58,7 +55,7 @@ class TogetherJudge(JudgevalJudge):
             )
             return res
         else:
-            error(f"Invalid input type received: {type(input)}")
+            judgeval_logger.error(f"Invalid input type received: {type(input)}")
             raise TypeError("Input must be a string or a list of dictionaries.")
 
     def load_model(self) -> str:
