@@ -3,12 +3,12 @@ Rules system for Judgeval that enables alerts based on metric thresholds.
 """
 
 from typing import Dict, List, Optional, Union, Any, Tuple
-from pydantic import BaseModel, Field, field_validator, ConfigDict
+from pydantic import BaseModel, Field, ConfigDict
 import asyncio
 from concurrent.futures import ThreadPoolExecutor
 import uuid
 
-from judgeval.scorers import APIJudgmentScorer, JudgevalScorer
+from judgeval.scorers import APIScorerConfig, BaseScorer
 from judgeval.utils.alerts import AlertStatus, AlertResult
 
 
@@ -18,7 +18,7 @@ class Condition(BaseModel):
 
     Example:
         {
-            "metric": FaithfulnessScorer(threshold=0.7)  # Must be a scorer object: APIJudgmentScorer, JudgevalScorer
+            "metric": FaithfulnessScorer(threshold=0.7)  # Must be a scorer object: APIScorerConfig, BaseScorer
         }
 
     The Condition class uses the scorer's threshold and success function internally.
@@ -26,13 +26,13 @@ class Condition(BaseModel):
 
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
-    metric: Union[APIJudgmentScorer, JudgevalScorer]
+    metric: Union[APIScorerConfig, BaseScorer]
 
     @property
     def metric_name(self) -> str:
         """Get the name of the metric for lookups in scores dictionary."""
         if hasattr(self.metric, "score_type"):
-            # Handle APIJudgmentScorer and JudgevalScorer which have score_type
+            # Handle APIScorerConfig and BaseScorer which have score_type
             return self.metric.score_type
         elif hasattr(self.metric, "__name__"):
             # Handle cases where metric has a __name__ attribute
@@ -58,8 +58,8 @@ class Condition(BaseModel):
         # Use the scorer's success check function if available
         if hasattr(self.metric, "success_check"):
             return self.metric.success_check()
-        elif hasattr(self.metric, "_success_check"):
-            return self.metric._success_check()
+        elif hasattr(self.metric, "success_check"):
+            return self.metric.success_check()
         else:
             # Fallback to default comparison (greater than or equal)
             return value >= self.threshold if self.threshold is not None else False
@@ -241,18 +241,6 @@ class Rule(BaseModel):
 
         return data
 
-    @field_validator("conditions")
-    def validate_conditions_not_empty(cls, v):
-        if not v:
-            raise ValueError("Conditions list cannot be empty")
-        return v
-
-    @field_validator("combine_type")
-    def validate_combine_type(cls, v):
-        if v not in ["all", "any"]:
-            raise ValueError(f"combine_type must be 'all' or 'any', got: {v}")
-        return v
-
 
 class RulesEngine:
     """
