@@ -1,46 +1,27 @@
 from judgeval.scorers.judgeval_scorers.api_scorers.execution_order import (
     ExecutionOrderScorer,
 )
-from judgeval.scorers.judgeval_scorers.api_scorers.json_correctness import (
-    JSONCorrectnessScorer,
-)
-from judgeval.scorers.judgeval_scorers.api_scorers.summarization import (
-    SummarizationScorer,
-)
 from judgeval.scorers.judgeval_scorers.api_scorers.hallucination import (
     HallucinationScorer,
 )
 from judgeval.scorers.judgeval_scorers.api_scorers.faithfulness import (
     FaithfulnessScorer,
 )
-from judgeval.scorers.judgeval_scorers.api_scorers.contextual_relevancy import (
-    ContextualRelevancyScorer,
-)
-from judgeval.scorers.judgeval_scorers.api_scorers.contextual_precision import (
-    ContextualPrecisionScorer,
-)
-from judgeval.scorers.judgeval_scorers.api_scorers.contextual_recall import (
-    ContextualRecallScorer,
-)
 from judgeval.scorers.judgeval_scorers.api_scorers.answer_relevancy import (
     AnswerRelevancyScorer,
 )
 from judgeval.scorers.judgeval_scorers.api_scorers.answer_correctness import (
     AnswerCorrectnessScorer,
 )
-from judgeval.scorers.judgeval_scorers.api_scorers.comparison import ComparisonScorer
 from judgeval.scorers.judgeval_scorers.api_scorers.instruction_adherence import (
     InstructionAdherenceScorer,
 )
-from judgeval.scorers.judgeval_scorers.api_scorers.groundedness import (
-    GroundednessScorer,
-)
 from judgeval.scorers.judgeval_scorers.api_scorers.derailment_scorer import (
     DerailmentScorer,
 )
 from judgeval.scorers.judgeval_scorers.api_scorers.tool_order import ToolOrderScorer
-from judgeval.scorers.judgeval_scorers.api_scorers.classifier_scorer import (
-    ClassifierScorer,
+from judgeval.scorers.judgeval_scorers.api_scorers.prompt_scorer import (
+    PromptScorer,
 )
 from judgeval.scorers.judgeval_scorers.api_scorers.tool_dependency import (
     ToolDependencyScorer,
@@ -57,11 +38,10 @@ __all__ = [
     "ContextualRecallScorer",
     "AnswerRelevancyScorer",
     "AnswerCorrectnessScorer",
-    "ComparisonScorer",
     "InstructionAdherenceScorer",
     "GroundednessScorer",
     "DerailmentScorer",
     "ToolOrderScorer",
-    "ClassifierScorer",
+    "PromptScorer",
     "ToolDependencyScorer",
 ]
