@@ -1,6 +1,7 @@
 import importlib.metadata
 from judgeval.utils.requests import requests
 import threading
+from judgeval.common.logger import judgeval_logger
 
 
 def check_latest_version(package_name: str = "judgeval"):
@@ -13,8 +14,8 @@ def check_latest_version(package_name: str = "judgeval"):
             latest_version = response.json()["info"]["version"]
 
             if current_version != latest_version:
-                print(
-                    f"\033[93mUPDATE AVAILABLE:\033[0m You are using '{package_name}=={current_version}', "
+                judgeval_logger.warning(
+                    f"UPDATE AVAILABLE: You are using '{package_name}=={current_version}', "
                     f"but the latest version is '{latest_version}'. While this version is still supported, "
                     f"we recommend upgrading to avoid potential issues or missing features: "
                     f"`pip install --upgrade {package_name}`"
